@@ -31,108 +31,9 @@ json_to_list <- function(string) {
 }
 
 #-------------------------------------------------------------------------------
-
 # Build a JSON string for a given object.
 json_build <- function(object) {
-  json <- json_build_any(object)
-  return(json)
-}
-
-json_build_any <- function(values) {
-  build_fn <- switch(
-    type(values),
-    structure = json_build_structure,
-    list = json_build_list,
-    map = json_build_map,
-    json_build_scalar
-  )
-  result <- build_fn(values)
-  return(result)
-}
-
-json_build_structure <- function(values) {
-  # TODO: Implement is valid check.
-
-  payload_name <- tag_get(values, "payload")
-  if (payload_name != "") {
-    values <- values[[payload_name]]
-    if (is_empty(values)) {
-      return(NULL)
-    }
-  }
-
-  v <- list()
-
-  for (key in names(values)) {
-    field <- values[[key]]
-
-    # TODO: Implement PkgPath.
-
-    if (tag_get(field, "json") == "-") {
-      next
-    }
-
-    if (tag_get(field, "location") != "") {
-      next
-    }
-
-    if (tag_get(field, "ignore") != "") {
-      next
-    }
-
-    if (can_set_idempotency_token(field)) {
-      token <- get_idempotency_token()
-      # Keep all tags when updating the field with the token.
-      attributes(token) <- attributes(field)
-      field <- token
-    }
-
-    # Skip empty fields.
-    if (is_empty(field)) {
-      next
-    }
-
-    name <- key
-    loc_name <- tag_get(field, "locationName")
-    if (loc_name != "") {
-      name <- loc_name
-    }
-
-    buf <- sprintf('"%s":%s', name, json_build_any(field))
-
-    v[[length(v) + 1]] <- buf
-  }
-
-  v <- sprintf("{%s}", paste(v, collapse = ","))
-}
-
-json_build_list <- function(values) {
-  v <- lapply(values, json_build_any)
-  l <- sprintf("[%s]", paste(v, collapse = ","))
-  return(l)
-}
-
-json_build_map <- function(values) {
-  v <- lapply(char_sort(names(values)), function(key) {
-    sprintf('"%s":%s', key, json_build_any(values[[key]]))
-  })
-  return(sprintf("{%s}", paste(v, collapse = ",")))
-}
-
-json_build_scalar <- function(values) {
-  s <- switch(
-    tag_get(values, "type"),
-    blob = sprintf('"%s"', convert_blob(values)),
-    boolean = convert_boolean(values),
-    double = as.character(values),
-    float = as.character(values),
-    integer = as.character(values),
-    long = as.character(values),
-    string = json_convert_string(values),
-    timestamp = as.character(as.numeric(values)),
-    sprintf('"%s"', values)
-  )
-  return(s)
+  return(json_build_any(object))
 }
 
 #-------------------------------------------------------------------------------
