@@ -32,9 +32,7 @@ mock2 <- function(..., cycle = FALSE, side_effect = NULL, envir = parent.frame()
       if (call_no > length(return_values) && !cycle) {
         stop("too many calls to mock object and cycle set to FALSE", call. = FALSE)
       }
-      value <- return_values[[
-        (call_no - 1) %% length(return_values) + 1
-      ]]
+      value <- return_values[[(call_no - 1) %% length(return_values) + 1]]
       return(eval(value, envir = return_values_env))
     }
 
@@ -46,7 +44,6 @@ mock2 <- function(..., cycle = FALSE, side_effect = NULL, envir = parent.frame()
   return(mock)
 }
 
-
 # retrieves a list of all arguments used for the last mocked function call
 mock_arg <- function(m) {
   env <- environment(m)
